/*
 * SessionImpl.java
 *
 * Created on May 14, 2005, 11:50 AM
 * Created by Detro - 566/2145
 */

package org.jaebi.server.auth;

import java.util.Date;

import org.jaebi.server.util.UniqueRandomIntFactory;
/**
 * Esempio di implementazione di Session.
 * 
 * In questo caso, il Session e' un semplice intero.
 * Ogni istanza e' diversa da ogni altra.
 * @class SessionImpl
 * @author detro
 */
public class SessionImpl implements Session {
    /**
     * Valore del Session 
     */
    private final int SessionImplValue;
    
	/**
	 * Data ultimo accesso.
	 */
	private final Date lastAccess;
    
	/**
     * Factory Statica di "Interi Unici e Random". 
     * La classe "SessionImpl" usa questa Factory statica nel costruttore
     * per ottenere un valore intero univoco e casuale, uno per ogni
     * istanza. 
     */
    private static UniqueRandomIntFactory intFactory = new UniqueRandomIntFactory();
    
    /**
     * 
     * Creates a new instance of SessionImpl.
     * 
     * In questa implementazione, ogni Session ha un valore
     * unico. Il valore e' un Intero.
     */
    public SessionImpl() {
		SessionImplValue = intFactory.createUniqueRandomInt();
		lastAccess = new Date();
    }
    
    public boolean equals( Object obj ) {
        if( obj == this ) {
            return true;
        }
        if( obj.getClass() == this.getClass() ) {
            SessionImpl session = ( SessionImpl ) obj;
            if( session.getValue() == this.getValue() ) {
                return true;
            }
        }
		
        return false;
    }
    
    public int hashCode() {
        return toString().hashCode();
    }
    
    public String toString() {
        return "Session Value: " + Integer.toString( SessionImplValue );
    }
    
    /**
     * Ritorna il valore del Session
     * 
     * @return Valore Session (Intero)
     */
    public int getValue() {
        return SessionImplValue;
    }    
}
