/*
 * UserContainer.java
 *
 * Created on May 14, 2005, 1:35 PM
 * Created by Detro - 566/2145
 */

package org.jaebi.server.core;
import java.util.ArrayList;
import java.util.Collection;

import org.jaebi.server.auth.Session;
/**
 * @author detro
 * 
 * Questa Interfaccia ha il compito di definire i metodi di base
 * per qualunque implementazione di UserContainer si voglia realizzare.
 * 
 * I metodi "critici" sono di tipo <i>syncronized</i>: per metodi critici
 * intendiamo tutti quei metodi in cui l'accesso concorrente puo'
 * provocare inconsistente o errori piu' o meno gravi.
 */
public interface UserContainer {
    /**
     * Aggiungi User al Container, se non presente.
     * 
     * Lo User viene istanziato internamente
     * al Container, quindi inserito.
     * 
     * @param nick Nick
     * @param session Session
     * @param type Tipo di User
     * @return "true" se lo User viene inserito (non era presente), "false" altrimenti
     */
    public boolean addUser( String nick, Session session, String type );
    
    /**
     * Aggiungi User al Container, se non presente.
     *
     * @param newUser User da aggiungere
     * @return "true" se lo User viene inserito (non era presente), "false" altrimenti
     */
    public boolean addUser( User newUser );
    
    /**
     * Elimina User dal Container in base al Session identificativo.
     * 
     * @param session Session identificativo
     */
    public boolean removeUser( Session session );
    
    /**
     * Recupera User in base al Session identificativo
     * 
     * @param session Session identificativo
     * @return Uno User, se presente uno User con quel Session, "null" altrimenti
     */
    public User getUser( Session session );
    
    /**
     * Recupera gli User in base al Nick.
     * 
     * @param nick Nick User da cercare
     * @return ArrayList di User
     */
    public ArrayList getUsersByNick( String nick );
    
    /**
     * Recupera gli User in base al Type.
     * 
     * @param type Type User da cercare
     * @return ArrayList di User
     */
    public ArrayList getUsersByType( String type );
    
    /**
     * Numero di User presenti nel Container
     *
     * @return Numero di User nel Container
     */
    public int size();
    
    /**
     * Rimuove tutti gli User presenti
     */
    public void clear();
    
    /**
     * Verifica che non ci siano User
     *
     * @return "true" se non ci sono User, "false" altrimenti
     */
    public boolean isEmpty();
    
    /**
     * Converte il Container in una Collection di User.
     * I cambiamenti esequiti sulla Collection generato si riflettono
     * sugli User presenti nel Container.
     *
     * @return Collection di tutti gli User presenti
     */
    public Collection toCollection();
    
    /**
     * Verifica se uno User con quel Session e' presente
     * 
     * @return "true" se lo User e' presente, "false" altrimenti
     */
    public boolean contains(Session session);
    
    /**
     * Converte il contenuto del Container in Stringa.
     *
     * Utile per l'auto conversione in String.
     * @return Stringa contenuti del Container
     */
    public String toString();
}
