/*
 * UserContainerImpl.java
 *
 * Created on May 15, 2005, 2:32 PM
 * Created by Detro - 566/2145
 */

package org.jaebi.server.core;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;

import org.jaebi.server.auth.Session;
/**
 * Container di User.
 * 
 * @class UserContainerImpl
 * @author detro
 */
public class UserContainerImpl implements UserContainer {
    /**
     * La scelta del Container e' caduta su una HashMap
     * per una questione di prestazioni. Poiche' la maggior parte delle
     * operazioni sul Container saranno di <b>1)Inserimento</b>, 
     * <b>2)Ricerca</b> e <b>3)Cancellazione</b>, 
     * e queste saranno quasi sempre
     * eseguite in base al Session identificativo, e' sembrata una buona
     * scelta <u>indicizzare gli User</u> in base all'oggetto
     * Session stesso. HashMap (che utilizza una funzione di Hashing
     * per l'indicizzazione) si presta ottimamente a questo scopo,
     * fornendo <u>tempi di accesso costanti</u>.
     */
    protected final HashMap container;
    
    /**
     * Creates a new instance of UserContainerImpl 
     */
    public UserContainerImpl() {
        container = new HashMap();
    }
    
    public boolean addUser( String nick, Session session, String type ) {
		User newUser = new User(nick, session, type);
		return addUser(newUser);
    }
    
    public synchronized boolean addUser( User newUser ) {
        if ( !contains( newUser.getSession() ) ) {
			container.put(newUser.getSession(), newUser);
			return true;
        }
        else 
			return false;
    }
    
    public synchronized boolean removeUser( Session session ) {
        User user = (User)container.remove(session);
        return user == null ? false : true;
    }
    
    public synchronized boolean contains(Session session) { 
        return container.containsKey(session);
    }
    
    public synchronized User getUser( Session session ) { 
        return (User)container.get(session); 
    }
    
    /**
     * Testare questo metodo e verificare che non
     * apporti cambiamenti al Container */
    public synchronized ArrayList getUsersByNick( String nick ) {
        Collection allUsers = container.values();
        ArrayList selected = new ArrayList();
        Iterator iter = allUsers.iterator();
        
        while( iter.hasNext() ) {
            User currUser = (User)iter.next();
            if ( currUser.getNick().equals(nick) )
                selected.add(currUser);
        }
        
        return selected;
    }
    
    /**
     * Testare questo metodo e verificare che non
     * apporti cambiamenti al Container */
    public synchronized ArrayList getUsersByType( String type ) {
        Collection allUsers = container.values();
        ArrayList selected = new ArrayList();
        Iterator iter = allUsers.iterator();
        
        while( iter.hasNext() ) {
            User currUser = (User)iter.next();
            if ( currUser.getType().equals(type) )
                selected.add(currUser);
        }
        
        return selected;
    }
    
    public synchronized int size() { return container.size(); }
    
    public synchronized void clear() { container.clear(); }
    
    public synchronized boolean isEmpty() { return container.isEmpty(); }
    
    public synchronized Collection toCollection() {
        return (Collection)container.values();
    }
    
    public String toString() {
        Iterator iter = container.values().iterator();
        StringBuffer buffer = new StringBuffer();
        
        while ( iter.hasNext() ) {
            buffer.append( iter.next().toString() + "\n");
        }
        return buffer.toString();
    }
}
