/*
 * Command.java
 *
 * Created on May 27, 2005, 7:13 PM
 * Created by Detro - 566/2145
 */

package org.jaebi.server.service;

import org.jaebi.server.service.exception.CommandExecException;

/**
 * @class Command
 * @author detro
 * 
 * Questa classe astratta "wrappa" i Comandi che uno User
 * richiede di eseguire su di un BackEnd.
 * Si e' deciso di implementare una "abstract class" e non di
 * usare una interfaccia perch ci sono metodi che presumibilmente
 * non cambieranno nell'implementazione concreta.
 */
abstract public class Command {
    /** Variabile booleana per verificare se un Command e'
     * stato eseguito o meno */
    protected boolean executed = false;
    
    /**
     * Verifica se una Command e' stata gia' eseguita.
     * 
     * @return "true" in caso affermativo
     */
    public boolean isExecuted() { return executed; }
    
    /**
     * Esegue Command sul BackEnd.
     * 
     * @return Rappresenta il risultato prodotto dalla Command
     * @exception Errore durante l'exec del Command
     */
    public abstract Object execute() throws CommandExecException; 
    
    /**
     * Restituisce il Tipo del Command
     *
     * @return Stringa contenente il "Type".
     */
    public abstract String getType();
    
    /**
     * Descrizione del Command
     *
     * @return Una Stringa che descrive il Command
     */
    public abstract String toString();
}
