/*
 * CommandFactory.java
 *
 * Created on May 27, 2005, 7:10 PM
 * Created by Detro - 566/2145
 */

package org.jaebi.server.service;
import org.jaebi.server.service.exception.CommandCreationException;

/**
 * @class Command Factory
 * @author detro
 *
 * Factory di Oggetti di tipo Command.
 * Questa e' una Abstract Class da cui estendere Factory
 * per istanziare implementazioni concrete di Command. 
 */
abstract public class CommandFactory {
    /** BackEndHandler da assegnare ai Command creati, e che "wrappa"
     * il BackEnd del servizio offerto */
    protected BackEndHandler backEndHandler;
    
    /**
     * Costruttore CommandFactory
     *
     * @param newBackEndHandler Il BackEnd che CommandFactory assegnera' ai Command
     */
    public CommandFactory(BackEndHandler newBackEndHandler) {
        backEndHandler = newBackEndHandler;
    }
    
    /**
     * Costruisci Command.
     *
     * Questo metodo costruisce un Command a partire da un
     * Object di descrizione. E' cosi' pensato per mantenere
     * generalita' nelle particolari implementazioni di Command.
     *
     * Ovviamente, il particolare tipo di operazioni per la costruzione
     * e la semantica associata all'Object sono da definire nella
     * particolare implementazione di CommandFactory.
     * 
     * @param request Richiesta da trasformare in una Command
     * @return Command
     */
    public abstract Command createCommand(Object request) throws CommandCreationException;
}
