/*
 * ServiceMediator.java
 *
 * Created on June 12, 2005, 3:59 PM
 * Created by Detro - 566/2145
 */

package org.jaebi.server.service;

import org.jaebi.server.core.User;
import org.jaebi.server.service.exception.ServiceMediatorExecException;

/**
 * @author detro
 * 
 * Questa interfaccia definisce una classe che segue
 * il "generico" Pattern Mediator, e si occupa di incapsulare
 * tutti i meccanismi di interazione tra le Classi
 * che propongono il servizio, semplificando sostanzialmente
 * l'uso del Service implementato.
 *
 * Il metodo e' volutamente generico proprio perche' non c'e'
 * alcuna conoscenza circa il funzionamento del particolare
 * Service implementato.
 */
public interface ServiceMediator {
    
    /**
     * Esegui il Servizio.
     *
     * @param user User che richiede l'uso del Service
     * @param request Definisce una richiesta
     * @return Risultato prodotto dal Service
     * @exception ServiceMediatorExecException Errore durante l'esecuzione
     */
    public Object executeService(User user, Object request) 
        throws ServiceMediatorExecException;
    
    /**
     * Esegui il Servizio.
     * 
     * Questo metodo e' identico a "executeService", con l'unica
     * differenza che serializza il risultato dell'esecuzione
     * in una stringa.
     *
     * @param user User che richiede l'uso del Service
     * @param request Definisce una richiesta
     * @return Risultato prodotto dal Service
     * @exception ServiceMediatorExecException Errore durante l'esecuzione
     */
    public String executeServiceToString(User user, Object request)
        throws ServiceMediatorExecException;
}
