/*
 * XRequestCommandFactory.java
 *
 * Created on June 5, 2005, 6:46 PM
 * Created by Detro - 566/2145
 */

package org.jaebi.server.service;

import org.jaebi.server.service.exception.CommandCreationException;
import org.jaebi.server.service.exception.XRequestCommandFactoryInitException;
import org.jaebi.server.service.exception.XRequestCommandInitException;
import org.jaebi.server.service.xml.JAXBMarshallerWrapper;
import org.jaebi.server.service.xml.JAXBMarshallerWrapperImpl;
import org.jaebi.server.service.xml.exception.JAXBMarshallerWrapperInitException;
import org.jaebi.server.service.xml.xrequest.Xrequest;


/**
 * @class XRequestCommandFactory
 * @author detro
 *
 * Factory di XRequestCommand.
 * Semplifica il processo di istanziazione di particolari
 * tipi di XRequest in base all'attributo "/xrequest/@type" presente
 * nell'XML-richiesta.
 */
public class XRequestCommandFactory extends CommandFactory {
    /** MarshallerWrapper necessario per tradurre
     * l'INPUT di tipo String in XRequest */
    private static JAXBMarshallerWrapper marshWrap;
    private static final String exceptionPrefix = "[BackEndHandlerImpl Exception]: ";
    
    /** 
     * Creates a new instance of XRequestCommandFactory 
     * 
     * @param newBackEndHandler BackEndHandler che la Factory assegnera'
     * ai Command creati
     *
     * @exception XRequestCommandFactoryInitException Errore 
     * durante l'inizializzazione, dovuto al MarshallerWrapper incorporato
     */
    public XRequestCommandFactory(BackEndHandler newBackEndHandler)
        throws XRequestCommandFactoryInitException {
        
        super(newBackEndHandler);
        
        try {
            marshWrap = 
                new JAXBMarshallerWrapperImpl("org.jaebi.server.service.xml.xrequest");
        } catch ( JAXBMarshallerWrapperInitException je ) {
            throw new XRequestCommandFactoryInitException( exceptionPrefix + je );
        }
    }
    
    public Command createCommand(Object request) 
        throws CommandCreationException {
               
        return createCommand((Xrequest)request);
    }
    
    /**
     * Costruisci XRequestCommand
     *
     * Questo metodo e' un OverLoading al metodo che prende 
     * in input Object: questo prende in input, direttamente,
     * un Xrequest.
     * 
     * @param request Richiesta da trasformare in una XRequestCommand
     * @return XRequestCommand[Delete|Insert|Select|Update]
     * @exception CommandCreationException Errore 
     * durante la creazione del Command (es., Xrequest malformato)
     */
    public XRequestCommand createCommand(Xrequest request)
        throws CommandCreationException {
        
        XRequestCommand newCommand = null;
        
        try {
            if ( request.getType().equalsIgnoreCase("delete") ) {
                newCommand = new XRequestCommandDelete(request, 
                        (BackEndHandlerImpl)this.backEndHandler);
            }
            
            else if ( request.getType().equalsIgnoreCase("insert") ) {
                newCommand = new XRequestCommandInsert(request, 
                        (BackEndHandlerImpl)this.backEndHandler);
            }

            else if ( request.getType().equalsIgnoreCase("select") ) {
                newCommand = new XRequestCommandSelect(request, 
                        (BackEndHandlerImpl)this.backEndHandler);
            }

            else if ( request.getType().equalsIgnoreCase("update") ) {
                newCommand = new XRequestCommandUpdate(request, 
                        (BackEndHandlerImpl)this.backEndHandler);
            }
            
            else throw new CommandCreationException( exceptionPrefix 
                    + " - Malformed XML: \"/xrequest/@type\" unknown." );
        } catch ( XRequestCommandInitException xreqe ) {
            throw new CommandCreationException( exceptionPrefix 
                    + xreqe + " - Type Selection Error." );
        }
        
        return newCommand;
    }
}
