/*
 * XRequestCommandInsert.java
 *
 * Created on June 8, 2005, 12:22 PM
 * Created by Detro - 566/2145
 */

package org.jaebi.server.service;

import org.jaebi.server.service.exception.BackEndHandlerGenericException;
import org.jaebi.server.service.exception.BackEndHandlerSQLCreationException;
import org.jaebi.server.service.exception.CommandExecException;
import org.jaebi.server.service.exception.XRequestCommandInitException;
import org.jaebi.server.service.xml.exception.JAXBXResponseFactoryBuildingException;
import org.jaebi.server.service.xml.xrequest.Xrequest;

/**
 * @class XRequestCommandInsert
 * @author detro
 *
 * Questa classe mappa uno Comando-Statement SQL di tipo INSERT.
 */
public class XRequestCommandInsert extends XRequestCommand {
    
    /** Creates a new instance of XRequestCommandSelect */
    public XRequestCommandInsert(Xrequest xrequestObj, BackEndHandlerImpl backEndHandler) 
        throws XRequestCommandInitException {
        
        super(xrequestObj, backEndHandler);
        
        /* Controlla se la Factory ha costruito 
         * l'XRequestCommand con l'Xrequest corretto */
        if ( !xrequestObj.getType().equalsIgnoreCase("insert") ) {
            throw new XRequestCommandInitException(
                    exceptionPrefix + "Xrequest Type does not match");
        }
    }
    
    /**
     * Restituisce il risultato della INSERT.
     *
     * @return Xresponse della Select
     */
    public Object execute() 
        throws CommandExecException {
        
        try {
            backEndHandler.insert( getAffectedTable() , getColumnsValue() );
        } catch ( BackEndHandlerGenericException e) {
            // Errore nel BackEnd
            try {
                return xresponseFactory.buildXresponse(false, 
                        "BackEnd Error - " + e.getMessage() );
            } catch ( JAXBXResponseFactoryBuildingException otherE ) {
                throw new CommandExecException( exceptionPrefix + otherE );
            }
        } catch ( BackEndHandlerSQLCreationException sqle) {
            // Errore nel BackEndHandler durante la creazione dell'SQL
            try {
                return xresponseFactory.buildXresponse(false, 
                        "Error in Submitted Data - " + sqle.getMessage() );
            } catch ( JAXBXResponseFactoryBuildingException otherE ) {
                throw new CommandExecException( exceptionPrefix + otherE );
            }
        }
        
        // Inserimento riuscito
        try {
            return xresponseFactory.buildXresponse(true, "INSERT #1 ROW" );
        } catch ( JAXBXResponseFactoryBuildingException otherE ) {
            throw new CommandExecException( exceptionPrefix + otherE );
        }
    }
}
