/*
 * XRequestCommandSelect.java
 *
 * Created on June 5, 2005, 7:13 PM
 * Created by Detro - 566/2145
 */

package org.jaebi.server.service;

import java.util.ArrayList;
import java.util.HashMap;
import org.jaebi.server.service.exception.BackEndHandlerGenericException;
import org.jaebi.server.service.exception.BackEndHandlerSQLCreationException;
import org.jaebi.server.service.exception.CommandExecException;
import org.jaebi.server.service.exception.XRequestCommandInitException;
import org.jaebi.server.service.xml.exception.JAXBXResponseFactoryBuildingException;
import org.jaebi.server.service.xml.xrequest.Xrequest;

/**
 * @class XRequestCommandSelect
 * @author detro
 *
 * Questa classe mappa uno Comando-Statement SQL di tipo SELECT.
 */
public class XRequestCommandSelect extends XRequestCommand {
    
    /** Creates a new instance of XRequestCommandSelect */
    public XRequestCommandSelect(Xrequest xrequestObj, BackEndHandlerImpl backEndHandler) 
        throws XRequestCommandInitException {
        
        super(xrequestObj, backEndHandler);
        
        /* Controlla se la Factory ha costruito 
         * l'XRequestCommand con l'Xrequest corretto */
        if ( !xrequestObj.getType().equalsIgnoreCase("select") ) {
            throw new XRequestCommandInitException(
                    exceptionPrefix + "Xrequest Type does not match");
        }
    }
    
    /**
     * Restituisce il risultato della SELECT.
     *
     * @return Xresponse della Select
     */
    public Object execute() 
     throws CommandExecException {
     
        try {
            ArrayList columnsName = getColumnsName();
            HashMap whereValues = getWhereColumnsValue();
            
            // Verifica se ci sono Columns da inserire nella Select
            if ( columnsName.size() == 0 )
                columnsName = null;
            
            // Verifica se ci sono condizioni di Where da inserire nella Select
            if ( whereValues.size() == 0 )
                whereValues = null;
            
            return xresponseFactory.buildXresponse(
                        backEndHandler.select( 
                            getAffectedTable(), 
                            columnsName,
                            whereValues
                        )
                    );
        } catch ( JAXBXResponseFactoryBuildingException e ) {
            // Errore durante la creazione dell'XResponse
            try {
                return xresponseFactory.buildXresponse(false, 
                        "Internal Error - " + e.getMessage() );
            } catch ( JAXBXResponseFactoryBuildingException otherE ) {
                throw new CommandExecException( exceptionPrefix + otherE );
            }
        } catch ( BackEndHandlerGenericException e) {
            // Errore nel BackEnd
            try {
                return xresponseFactory.buildXresponse(false, 
                        "BackEnd Error - " + e.getMessage() );
            } catch ( JAXBXResponseFactoryBuildingException otherE ) {
                throw new CommandExecException( exceptionPrefix + otherE );
            }
        } catch ( BackEndHandlerSQLCreationException sqle) {
            // Errore nel BackEndHandler durante la creazione dell'SQL
            try {
                return xresponseFactory.buildXresponse(false, 
                        "Error in Submitted Data - " + sqle.getMessage() );
            } catch ( JAXBXResponseFactoryBuildingException otherE ) {
                throw new CommandExecException( exceptionPrefix + otherE );
            }
        }
    }
    
}
