/*
 * XRequestCommandUpdate.java
 *
 * Created on June 9, 2005, 12:21 PM
 * Created by Detro - 566/2145
 */

package org.jaebi.server.service;

import org.jaebi.server.service.exception.BackEndHandlerGenericException;
import org.jaebi.server.service.exception.BackEndHandlerSQLCreationException;
import org.jaebi.server.service.exception.CommandExecException;
import org.jaebi.server.service.exception.XRequestCommandInitException;
import org.jaebi.server.service.xml.exception.JAXBXResponseFactoryBuildingException;
import org.jaebi.server.service.xml.xrequest.Xrequest;

/**
 * @class XRequestCommandUpdate
 * @author detro
 *
 * Questa classe mappa uno Comando-Statement SQL di tipo UPDATE.
 */
public class XRequestCommandUpdate extends XRequestCommand {
    
    /** Creates a new instance of XRequestCommandSelect */
    public XRequestCommandUpdate(Xrequest xrequestObj, BackEndHandlerImpl backEndHandler) 
        throws XRequestCommandInitException {
        
        super(xrequestObj, backEndHandler);
        
        /* Controlla se la Factory ha costruito 
         * l'XRequestCommand con l'Xrequest corretto */
        if ( !xrequestObj.getType().equalsIgnoreCase("update") ) {
            throw new XRequestCommandInitException(
                    exceptionPrefix + "Xrequest Type does not match");
        }
    }
    
    /**
     * Restituisce il risultato della UPDATE.
     *
     * @return Xresponse della Select
     */
    public Object execute() 
        throws CommandExecException {
        
        int affectedRows;
        
        try {
            if ( getWhereColumnsName().size() == 0 ) {
                affectedRows = backEndHandler.update(
                    getAffectedTable(),
                    getColumnsValue()
                );
            } else {
                affectedRows = backEndHandler.update(
                    getAffectedTable(),
                    getColumnsValue(),
                    getWhereColumnsValue()
                );
            }
            
            return xresponseFactory.buildXresponse(true, 
                    "UPDATE #" + affectedRows + " ROWS" );
            
        } catch ( JAXBXResponseFactoryBuildingException e ) {
            // Errore durante la creazione dell'XResponse
            try {
                return xresponseFactory.buildXresponse(false, 
                        "Internal Error - " + e.getMessage() );
            } catch ( JAXBXResponseFactoryBuildingException otherE ) {
                throw new CommandExecException( exceptionPrefix + otherE );
            }
        } catch ( BackEndHandlerGenericException e) {
            // Errore nel BackEnd
            try {
                return xresponseFactory.buildXresponse(false, 
                        "BackEnd Error - " + e.getMessage() );
            } catch ( JAXBXResponseFactoryBuildingException otherE ) {
                throw new CommandExecException( exceptionPrefix + otherE );
            }
        } catch ( BackEndHandlerSQLCreationException sqle) {
            // Errore nel BackEndHandler durante la creazione dell'SQL
            try {
                return xresponseFactory.buildXresponse(false, 
                        "Error in Submitted Data - " + sqle.getMessage() );
            } catch ( JAXBXResponseFactoryBuildingException otherE ) {
                throw new CommandExecException( exceptionPrefix + otherE );
            }
        }
    }
    
}
