/*
 * JAXBMarshallerWrapper.java
 *
 * Created on May 29, 2005, 4:14 PM
 * Created by Detro - 566/2145
 */

package org.jaebi.server.service.xml;

import java.io.File;
import java.io.InputStream;
import java.net.URL;

import javax.xml.transform.Source;

import org.jaebi.server.service.xml.exception.JAXBMarshallerWrapperMarshallException;
import org.jaebi.server.service.xml.exception.JAXBMarshallerWrapperUnmarshallException;
/**
 * Interfaccia da implementare per agevolare le
 * operaziodi Marshalling ed Unmarshalling di un XML
 * Bindato con JAXB (JAva Xml Binding).
 *
 * @author detro
 */
public interface JAXBMarshallerWrapper {
    /**
     * Marshall di un XML Bindato con JAXB.
     * 
     * Mashallare significa, in sostanza, "trasformare in Stringa",
     * serializzando quindi l'Oggetto XML in una "forma" piu'
     * comune e trasportabile.
     * 
     * @param marshallable Object XML marshallabile
     * @return Stringa XML
     * @exception JAXBMarshallerWrapperUnmarshallException
     */
    public String marshall(Object marshallable) 
        throws JAXBMarshallerWrapperMarshallException;
    
    /**
     * Unmarshall di una Stringa in un XML JAXB Object.
     * 
     * Converte in una struttura di oggetti JAXB
     * una Stringa contenente XML.
     * 
     * @param xmlString Stringa contenente XML
     * @return Object JAXB
     * @exception JAXBMarshallerWrapperUnmarshallException
     */
    public Object unmarshall(String xmlString) 
        throws JAXBMarshallerWrapperUnmarshallException;
    
    /**
     * Unmarshall di un URL che si riferisce ad un XML in un XML JAXB Object.
     * 
     * Converte in una struttura di oggetti JAXB
     * un URL contenente XML.
     * 
     * @param url URL contenente XML
     * @return Object JAXB
     * @exception JAXBMarshallerWrapperUnmarshallException
     */
    public Object unmarshall(URL url) 
        throws JAXBMarshallerWrapperUnmarshallException;
    
    /**
     * Unmarshall di un File XML in un XML JAXB Object.
     * 
     * Converte in una struttura di oggetti JAXB
     * un File contenente XML.
     * 
     * @param file File contenente XML
     * @return Object JAXB
     * @exception JAXBMarshallerWrapperUnmarshallException
     */
    public Object unmarshall(File file) 
        throws JAXBMarshallerWrapperUnmarshallException;
    
    /**
     * Unmarshall di un InputStream XML in un XML JAXB Object.
     * 
     * Converte in una struttura di oggetti JAXB
     * un InputStream contenente XML.
     * 
     * @param inputStream InputStream contenente XML
     * @return Object JAXB
     * @exception JAXBMarshallerWrapperUnmarshallException
     */
    public Object unmarshall(InputStream inputStream) 
        throws JAXBMarshallerWrapperUnmarshallException;
    
    public Object unmarshall(Source source) 
        throws JAXBMarshallerWrapperUnmarshallException;
    
    /**
     * Attiva/Disattiva il Marshalling "formattato",
     * cioe' con Indentazione dell'XML.
     * 
     * @param value "true" per attivare, "false" per disattivare
     * @exception JAXBMarshallerWrapperUnmarshallException
     */
    public void setFormattedMarshalling(boolean value) 
        throws JAXBMarshallerWrapperMarshallException;
    
    /**
     * Verifica se e' attivo il Marshalling formattato.
     * 
     * @return "true" se attivo, "false" altrimenti
     */
    public boolean isFormattedMarshalling();
}
